# Generated by Django 5.2.8 on 2025-11-22 07:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('geobank', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='country',
            name='flag',
        ),
        migrations.AddField(
            model_name='country',
            name='flag_png',
            field=models.URLField(blank=True, max_length=500, null=True, verbose_name='Flag PNG URL'),
        ),
        migrations.AddField(
            model_name='country',
            name='flag_svg',
            field=models.URLField(blank=True, max_length=500, null=True, verbose_name='Flag PNG URL'),
        ),
    ]
